W

Struct W 

pub struct W(/* private fields */);
Register DEV_KEY_CTL0 writer

Implementations

Source

impl W

pub fn allowed( &mut self, ) -> BitWriterRaw<'_, u32, DEV_KEY_CTL0_SPEC, bool, BitM, 0>

Bit 0 - Specifies if a LOAD_DEV_KEY instruction is allowed to use the device key in memory: ‘0’: Not allowed. ‘1’: Allowed. Note: For successful completion of a LOAD_DEV_KEY instruction, both the associated DEV_KEY_ADDR_CTL.VALID and DEV_KEY_CTL.ALLOWED fields must be ‘1’. On successful instruction completion, DEV_KEY_STATUS.LOADED is set to ‘1’. On unsuccessful completion, the instruction FIFO is cleared and the IP is locked; an Active reset or an IP reset (CTL.ENABLED), which reinitializes the IP, is required. Note: A LOAD_DEV_KEY loads the device key from memory with protection context ‘0’.

pub unsafe fn bits(&mut self, bits: u32) -> &mut W

Writes raw bits to the register.

Methods from Deref<Target = W<DEV_KEY_CTL0_SPEC>>

pub unsafe fn bits(&mut self, bits: <REG as RegisterSpec>::Ux) -> &mut W<REG>

Writes raw bits to the register.

Safety

Read datasheet or reference manual to find what values are allowed to pass.