pub struct R(/* private fields */);Expand description
Register FM_CODE_MARGIN reader
Implementations
Sourceimpl R
impl R
Sourcepub fn margin_dcs_trim(&self) -> FieldReaderRaw<u16, u16>
pub fn margin_dcs_trim(&self) -> FieldReaderRaw<u16, u16>
Bits 0:8 - see above table to set the DCS reference current value to be used during Margin mode. (default set to 5uS = 0x143) which gives a Margin to the Erase side. 7uA would probably be used for Margin to the PGM side
Sourcepub fn margin_dcs_trim_en(&self) -> BitReaderRaw<bool>
pub fn margin_dcs_trim_en(&self) -> BitReaderRaw<bool>
Bit 9 - 0: internal device defaults used from Margin reads reference current 1: MARGIN_DCS_TRIM configuration is used during Margin read
Sourcepub fn margin_rdreg_trim(&self) -> FieldReaderRaw<u8, u8>
pub fn margin_rdreg_trim(&self) -> FieldReaderRaw<u8, u8>
Bits 10:15 - rdreg_c trim to be used in Margin mode if enabled by MARGIN_MODE_RDREG_CHNG_EN
Sourcepub fn margin_pgm_ers_b(&self) -> BitReaderRaw<bool>
pub fn margin_pgm_ers_b(&self) -> BitReaderRaw<bool>
Bit 29 - 0: ERS Margin is checked 1: PGM Margin is checked
Sourcepub fn margin_mode_rdreg_chng_en(&self) -> BitReaderRaw<bool>
pub fn margin_mode_rdreg_chng_en(&self) -> BitReaderRaw<bool>
Bit 30 - when set will also use the MARGIN_RDREG_TRIM from above. Default is not to use
Sourcepub fn margin_mode_en(&self) -> BitReaderRaw<bool>
pub fn margin_mode_en(&self) -> BitReaderRaw<bool>
Bit 31 - when set puts the s40ect Flash IP In Margin mode
Methods from Deref<Target = R<FM_CODE_MARGIN_SPEC>>
Sourcepub fn bits(&self) -> <REG as RegisterSpec>::Ux
pub fn bits(&self) -> <REG as RegisterSpec>::Ux
Reads raw bits from register.