pub struct W(/* private fields */);Expand description
Register CAL_CTL writer
Implementations
Sourceimpl W
impl W
Sourcepub fn calib_val(
&mut self,
) -> FieldWriterRaw<'_, u32, CAL_CTL_SPEC, u8, u8, Unsafe, 6, 0>
pub fn calib_val( &mut self, ) -> FieldWriterRaw<'_, u32, CAL_CTL_SPEC, u8, u8, Unsafe, 6, 0>
Bits 0:5 - Calibration value for absolute frequency (at a fixed temperature). Each step causes 128 ticks to be added or removed each hour. Effectively that means that each step is 1.085ppm (= 128/(606032,768)) when CAL_COMP_PER_MIN is set at default value. Positive values 0x01-0x3c (1..60) add pulses, negative values remove pulses, thus giving a range of +/-65.1 ppm (limited by 60 minutes per hour, not the range of this field) when CAL_COMP_PER_MIN is set at default value . Calibration is performed hourly, starting at 59 minutes and 59 seconds, and applied as 64 ticks every 30 seconds until there have been 2*CALIB_VAL adjustments when CAL_COMP_PER_MIN is set at default value .
Sourcepub fn calib_sign(
&mut self,
) -> BitWriterRaw<'_, u32, CAL_CTL_SPEC, bool, BitM, 6>
pub fn calib_sign( &mut self, ) -> BitWriterRaw<'_, u32, CAL_CTL_SPEC, bool, BitM, 6>
Bit 6 - Calibration sign: 0= Negative sign: remove pulses (it takes more clock ticks to count one second) 1= Positive sign: add pulses (it takes less clock ticks to count one second)
Sourcepub fn cal_comp_per_min(
&mut self,
) -> FieldWriterRaw<'_, u32, CAL_CTL_SPEC, u8, CAL_COMP_PER_MIN_A, Safe, 2, 16>
pub fn cal_comp_per_min( &mut self, ) -> FieldWriterRaw<'_, u32, CAL_CTL_SPEC, u8, CAL_COMP_PER_MIN_A, Safe, 2, 16>
Bits 16:17 - Select how many time calibration is performed per minute per step of 64 , each time a 64 step is added or substracted one unit 2/4/8/16*CALIB_VAL is substracted.
Sourcepub fn cal_sel(
&mut self,
) -> FieldWriterRaw<'_, u32, CAL_CTL_SPEC, u8, CAL_SEL_A, Safe, 2, 28>
pub fn cal_sel( &mut self, ) -> FieldWriterRaw<'_, u32, CAL_CTL_SPEC, u8, CAL_SEL_A, Safe, 2, 28>
Bits 28:29 - Select calibration wave output signal
Sourcepub fn cal_out(&mut self) -> BitWriterRaw<'_, u32, CAL_CTL_SPEC, bool, BitM, 31>
pub fn cal_out(&mut self) -> BitWriterRaw<'_, u32, CAL_CTL_SPEC, bool, BitM, 31>
Bit 31 - Output enable for wave signal for calibration and allow CALIB_VAL to be written.