pub struct W(/* private fields */);Expand description
Register DEV_KEY_CTL0 writer
Implementations
Sourceimpl W
impl W
Sourcepub fn allowed(
&mut self,
) -> BitWriterRaw<'_, u32, DEV_KEY_CTL0_SPEC, bool, BitM, 0>
pub fn allowed( &mut self, ) -> BitWriterRaw<'_, u32, DEV_KEY_CTL0_SPEC, bool, BitM, 0>
Bit 0 - Specifies if a LOAD_DEV_KEY instruction is allowed to use the device key in memory: ‘0’: Not allowed. ‘1’: Allowed. Note: For successful completion of a LOAD_DEV_KEY instruction, both the associated DEV_KEY_ADDR_CTL.VALID and DEV_KEY_CTL.ALLOWED fields must be ‘1’. On successful instruction completion, DEV_KEY_STATUS.LOADED is set to ‘1’. On unsuccessful completion, the instruction FIFO is cleared and the IP is locked; an Active reset or an IP reset (CTL.ENABLED), which reinitializes the IP, is required. Note: A LOAD_DEV_KEY loads the device key from memory with protection context ‘0’.
Methods from Deref<Target = W<DEV_KEY_CTL0_SPEC>>